/*
 * Non-Commercial License
 * 
 * Owner: Whisperstream Research Group, Copyright 2004
 * 
 * DEFINITIONS
 * "Software" means source code (libraries) and associated documentation and data.
 * "Research Use" means research, evaluation, and educational use, excluding use or
 *  distribution for direct or indirect commercial (including strategic) gain or advantage.
 * 
 * PURPOSE
 * The purpose of licensing the Software is to promote education and research and to allow
 * feedback from the development community.
 * 
 * TERMS
 * You are granted a perpetual, royalty-free, non-exclusive license, subject to the
 * claims of any third parties, to use the Software for Research Use only, provided you
 * agree to and comply with any and all conditions in this license. COMMERCIAL USE AND 
 * DISTRIBUTION OF THE SOFTWARE IS NOT PERMITTED UNDER THIS LICENSE. 
 * If you are interested in other licensing alternatives, please contact the copyright owners.
 * 
 * Contributors grant to the copyright owners a world-wide, royalty-free, perpetual, 
 * non-exclusive license, subject to third party intellectual property claims: to use,
 * reproduce, modify, display, perform, sub-license, sell, and distribute the contributor's
 * modifications in software developed by the copyright owners, even if such software is released
 * under a different license. 
 * 
 * BECAUSE THE SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY FOR THE SOFTWARE,
 * TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT
 * HOLDERS AND/OR OTHER PARTIES PROVIDE THE PROGRAM "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER 
 * EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY 
 * AND FITNESS FOR A PARTICULAR PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE 
 * PROGRAM IS WITH YOU. SHOULD THE PROGRAM PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL NECESSARY SERVICING,
 * REPAIR OR CORRECTION. 

 * IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING WILL ANY COPYRIGHT HOLDER,
 * OR ANY OTHER PARTY WHO MAY MODIFY AND/OR REDISTRIBUTE THE SOFTWARE AS PERMITTED ABOVE, BE LIABLE
 * TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES ARISING OUT
 * OF THE USE OR INABILITY TO USE THE PROGRAM (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
 * RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A FAILURE OF THE PROGRAM TO OPERATE
 * WITH ANY OTHER PROGRAMS), EVEN IF SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGES. 
*/
using System;

namespace Whisperstream.SerialComm.Framework.Interfaces
{
	/// <summary>
	/// The framework's Phone Settings interface
	/// </summary>
	public interface IPhoneSettingsModule
	{
		/// <summary>
		/// Resets the phone serial port settings
		/// </summary>
		/// <returns>true if the command was successful, false otherwise</returns>
		bool RestoreStoredProfile();

		/// <summary>
		/// gets the remaining battery charge
		/// </summary>
		/// <returns>a number between 1 and 0</returns>
		double GetBatteryCharge();

		/// <summary>
		/// gets the current call signal quality
		/// </summary>
		/// <returns>a floating point number</returns>
		double GetSignalQuality();

		/// <summary>
		/// gets the manufacturuer
		/// </summary>
		/// <returns>a string describing the manufacturer</returns>
		string GetManufacturerIdentification();

		/// <summary>
		/// gets the phone make and model
		/// </summary>
		/// <returns>a string describing the phone's make and model</returns>
		string GetModelIdentification();

		/// <summary>
		/// gets the software version installed on the phone
		/// </summary>
		/// <returns>a string describing the firmware version</returns>
		string GetFirmwareVersion();

		/// <summary>
		/// gets the equipment serial number
		/// </summary>
		/// <returns>a string describing the equipment serial number or IMIE</returns>
		string GetEquipmentSerialNumber();
	}
}
