/*
 * Non-Commercial License
 * 
 * Owner: Whisperstream Research Group, Copyright 2004
 * 
 * DEFINITIONS
 * "Software" means source code (libraries) and associated documentation and data.
 * "Research Use" means research, evaluation, and educational use, excluding use or
 *  distribution for direct or indirect commercial (including strategic) gain or advantage.
 * 
 * PURPOSE
 * The purpose of licensing the Software is to promote education and research and to allow
 * feedback from the development community.
 * 
 * TERMS
 * You are granted a perpetual, royalty-free, non-exclusive license, subject to the
 * claims of any third parties, to use the Software for Research Use only, provided you
 * agree to and comply with any and all conditions in this license. COMMERCIAL USE AND 
 * DISTRIBUTION OF THE SOFTWARE IS NOT PERMITTED UNDER THIS LICENSE. 
 * If you are interested in other licensing alternatives, please contact the copyright owners.
 * 
 * Contributors grant to the copyright owners a world-wide, royalty-free, perpetual, 
 * non-exclusive license, subject to third party intellectual property claims: to use,
 * reproduce, modify, display, perform, sub-license, sell, and distribute the contributor's
 * modifications in software developed by the copyright owners, even if such software is released
 * under a different license. 
 * 
 * BECAUSE THE SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY FOR THE SOFTWARE,
 * TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT
 * HOLDERS AND/OR OTHER PARTIES PROVIDE THE PROGRAM "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER 
 * EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY 
 * AND FITNESS FOR A PARTICULAR PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE 
 * PROGRAM IS WITH YOU. SHOULD THE PROGRAM PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL NECESSARY SERVICING,
 * REPAIR OR CORRECTION. 

 * IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING WILL ANY COPYRIGHT HOLDER,
 * OR ANY OTHER PARTY WHO MAY MODIFY AND/OR REDISTRIBUTE THE SOFTWARE AS PERMITTED ABOVE, BE LIABLE
 * TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES ARISING OUT
 * OF THE USE OR INABILITY TO USE THE PROGRAM (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
 * RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A FAILURE OF THE PROGRAM TO OPERATE
 * WITH ANY OTHER PROGRAMS), EVEN IF SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGES. 
*/
using System;
using System.Collections;
using Whisperstream.SerialComm.Framework.Phonebook;
		  
namespace Whisperstream.SerialComm.Framework.Interfaces
{
	/// <summary>
	/// The framework's Phonebook interface
	/// </summary>
	public interface IPhonebookModule
	{
		/// <summary>
		/// Adds a new entry to the phonebook
		/// </summary>
		/// <param name="p">the phone book entry</param>
		/// <returns>true if the command was successful, false otherwise</returns>
		bool AddPhonebookEntry(PhonebookEntry p);

		/// <summary>
		/// Deletes a phonebook entry
		/// </summary>
		/// <param name="index">the entry to remove</param>
		/// <returns>true if the command was successful, false otherwise</returns>
		bool RemovePhonebookEntry(int index);

		/// <summary>
		/// returns true or false if the memory store is supported by this model phone
		/// </summary>
		/// <param name="ms">the memory store type to check</param>
		/// <returns>true if the memory store type is supported, false otherwise</returns>
		bool IsMemoryStoreSupported(MemoryStore ms);

		/// <summary>
		/// returns a list of supported memory store types
		/// </summary>
		/// <returns>a list of supported memory store types</returns>
		ArrayList GetSupportedMemoryStores();

		/// <summary>
		/// gets/sets the current memory store
		/// </summary>
		MemoryStore CurrentPhonebookMemoryStore{ get; set;}

		/// <summary>
		/// reads a phonebook entry from the phone's memory
		/// </summary>
		/// <param name="entry">the entry index in the phonebook</param>
		/// <returns>the phonebook entry or null if no entry is found</returns>
		PhonebookEntry ReadPhonebookEntry(int entry);

		/// <summary>
		/// gets a hashtable of all the phonebook entries in the phonebook
		/// </summary>
		/// <returns>a hashtable of all the phonebook entries in the phonebook, indexed
		/// by the phone number</returns>
		Hashtable GetAddressBook();
	}
}
