/*
 * Non-Commercial License
 * 
 * Owner: Whisperstream Research Group, Copyright 2004
 * 
 * DEFINITIONS
 * "Software" means source code (libraries) and associated documentation and data.
 * "Research Use" means research, evaluation, and educational use, excluding use or
 *  distribution for direct or indirect commercial (including strategic) gain or advantage.
 * 
 * PURPOSE
 * The purpose of licensing the Software is to promote education and research and to allow
 * feedback from the development community.
 * 
 * TERMS
 * You are granted a perpetual, royalty-free, non-exclusive license, subject to the
 * claims of any third parties, to use the Software for Research Use only, provided you
 * agree to and comply with any and all conditions in this license. COMMERCIAL USE AND 
 * DISTRIBUTION OF THE SOFTWARE IS NOT PERMITTED UNDER THIS LICENSE. 
 * If you are interested in other licensing alternatives, please contact the copyright owners.
 * 
 * Contributors grant to the copyright owners a world-wide, royalty-free, perpetual, 
 * non-exclusive license, subject to third party intellectual property claims: to use,
 * reproduce, modify, display, perform, sub-license, sell, and distribute the contributor's
 * modifications in software developed by the copyright owners, even if such software is released
 * under a different license. 
 * 
 * BECAUSE THE SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY FOR THE SOFTWARE,
 * TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT
 * HOLDERS AND/OR OTHER PARTIES PROVIDE THE PROGRAM "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER 
 * EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY 
 * AND FITNESS FOR A PARTICULAR PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE 
 * PROGRAM IS WITH YOU. SHOULD THE PROGRAM PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL NECESSARY SERVICING,
 * REPAIR OR CORRECTION. 

 * IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING WILL ANY COPYRIGHT HOLDER,
 * OR ANY OTHER PARTY WHO MAY MODIFY AND/OR REDISTRIBUTE THE SOFTWARE AS PERMITTED ABOVE, BE LIABLE
 * TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES ARISING OUT
 * OF THE USE OR INABILITY TO USE THE PROGRAM (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
 * RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A FAILURE OF THE PROGRAM TO OPERATE
 * WITH ANY OTHER PROGRAMS), EVEN IF SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGES. 
*/
using System;

using Whisperstream.SerialComm.IO;
using Whisperstream.SerialComm.Framework.Interfaces;

namespace Whisperstream.NokiaAPI.Common
{
	/// <summary>
	/// Base class for all Nokia 6210 module implmentations
	/// </summary>
	public abstract class ApiModuleBase
	{
		protected ISerialIO iSerialIO;

		/// <summary>
		/// ApiModuleBase constructor
		/// </summary>
		/// <param name="iSerialIO">an ISerialIO interface</param>
		/// <exception cref="ArgumentNullException">thrown if iSerialIO == null</exception>
		public ApiModuleBase(ISerialIO iSerialIO)
		{
			if(iSerialIO == null)
				throw new ArgumentNullException("iSerialIO", "iSerialIO cannot be null");

			this.iSerialIO = iSerialIO;
			iSerialIO.Open();
		}

		/// <summary>
		/// Sends a command synchronusly to the serial port, uses the default endTokens and command timeout
		/// </summary>
		/// <param name="command">the data or command to send</param>
		/// <returns>the response to sending the data</returns>
		/// <exception cref="CommandTimeoutException">thrown if the default command timeout
		/// is exceeded during the call</exception>
		protected string SendCommand(string command)
		{
			return iSerialIO.SendCommand(command);
		}

		/// <summary>
		/// Sends a command synchronusly to the serial port, uses the default command timeout
		/// </summary>
		/// <param name="command">the data or command to send</param>
		/// <param name="endTokens">the endtokens to search for</param>
		/// <returns>the response to sending the data</returns>
		/// <exception cref="CommandTimeoutException">thrown if the default command timeout
		/// is exceeded during the call</exception>
		protected string SendCommand(string command, string[] endTokens)
		{
			return iSerialIO.SendCommand(command, endTokens, iSerialIO.CommandTimeout);
		}
	}
}
