/*
 * Non-Commercial License
 * 
 * Owner: Whisperstream Research Group, Copyright 2004
 * 
 * DEFINITIONS
 * "Software" means source code (libraries) and associated documentation and data.
 * "Research Use" means research, evaluation, and educational use, excluding use or
 *  distribution for direct or indirect commercial (including strategic) gain or advantage.
 * 
 * PURPOSE
 * The purpose of licensing the Software is to promote education and research and to allow
 * feedback from the development community.
 * 
 * TERMS
 * You are granted a perpetual, royalty-free, non-exclusive license, subject to the
 * claims of any third parties, to use the Software for Research Use only, provided you
 * agree to and comply with any and all conditions in this license. COMMERCIAL USE AND 
 * DISTRIBUTION OF THE SOFTWARE IS NOT PERMITTED UNDER THIS LICENSE. 
 * If you are interested in other licensing alternatives, please contact the copyright owners.
 * 
 * Contributors grant to the copyright owners a world-wide, royalty-free, perpetual, 
 * non-exclusive license, subject to third party intellectual property claims: to use,
 * reproduce, modify, display, perform, sub-license, sell, and distribute the contributor's
 * modifications in software developed by the copyright owners, even if such software is released
 * under a different license. 
 * 
 * BECAUSE THE SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY FOR THE SOFTWARE,
 * TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT
 * HOLDERS AND/OR OTHER PARTIES PROVIDE THE PROGRAM "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER 
 * EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY 
 * AND FITNESS FOR A PARTICULAR PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE 
 * PROGRAM IS WITH YOU. SHOULD THE PROGRAM PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL NECESSARY SERVICING,
 * REPAIR OR CORRECTION. 

 * IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING WILL ANY COPYRIGHT HOLDER,
 * OR ANY OTHER PARTY WHO MAY MODIFY AND/OR REDISTRIBUTE THE SOFTWARE AS PERMITTED ABOVE, BE LIABLE
 * TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES ARISING OUT
 * OF THE USE OR INABILITY TO USE THE PROGRAM (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
 * RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A FAILURE OF THE PROGRAM TO OPERATE
 * WITH ANY OTHER PROGRAMS), EVEN IF SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGES. 
*/
using System;
using System.Collections.Specialized;

using Whisperstream.SerialComm.Framework.Interfaces;
using Whisperstream.SMSProcessor.Interfaces;
using Whisperstream.SMSProcessor.Log;

namespace Whisperstream.SMSProcessor
{
	/// <summary>
	/// Provides methods and memer variables that may be of use to implementations of
	/// the IMessageProcessor interface
	/// </summary>
	public class ProcessorHelperData
	{
		private string password = null;
		private IMobilePhoneAPI iMobilePhoneAPI = null;
		private string smtpServer = null;
		private NameValueCollection appSettings = null;

		/// <summary>
		/// ProcessorHelperData constructor
		/// </summary>
		/// <param name="password">the master password</param>
		/// <param name="appSettings">the AppSettings structure from the config file</param>
		/// <param name="iMobilePhoneAPI">the IMobilePhoneAPI interface implmentation connected to the COM serial port</param>
		public ProcessorHelperData(
			string password,
			NameValueCollection appSettings,
			IMobilePhoneAPI iMobilePhoneAPI)
		{
			this.password = password;
			this.appSettings = appSettings;
			this.iMobilePhoneAPI = iMobilePhoneAPI;
		}

		/// <summary>
		/// Checks if the password matches the master password set duing initialization.
		/// This allows the implementor of the IMessageProcessor interface to check if they
		/// has received the master password, yet not necessarily know what it is until a match is found.
		/// </summary>
		/// <param name="password">the password to test</param>
		/// <returns>true if the password matches the master password, false otherwise</returns>
		public bool IsMasterPasswordMatch(string password)
		{
			return this.password == password;
		}

		/// <summary>
		/// Gets the IMobilePhoneAPI interface implmentation connected to the COM serial port
		/// </summary>
		public IMobilePhoneAPI IMobilePhoneAPI { get { return iMobilePhoneAPI; }}

		/// <summary>
		/// Gets the current Smtp server
		/// </summary>
		public string SmtpServer { get { return smtpServer; } set { smtpServer = value; } }

		/// <summary>
		/// Returns an ILog log4net interface implementation, so that any class that implements
		/// the IMessageProcessor interface will have access to a logging mechanism if so required
		/// </summary>
		/// <param name="instance">the instance of the IMessageProcessor implementation</param>
		/// <returns>an ILog interface implmentation</returns>
		public ILog GetLogger(System.Type type)
		{
			return LogFactory.Instance.GetLogger(type);
		}

		/// <summary>
		/// Gets a value from the application's application settings config file
		/// </summary>
		/// <param name="key">the key to search for</param>
		/// <returns>the value from the application settings or null</returns>
		public string GetSetting(string key)
		{
			if(appSettings == null || key == null)
				return null;

			return appSettings[key];
		}

	}
}
